<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Inch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Fod</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Mile</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Microinch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Micron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hektometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Lightyear</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>Af lag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Af blok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Rød</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Grøn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Blå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Gul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Mørkerød</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Mørkegrøn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Mørkeblå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Mørk cyan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Mørk magenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Mørkegul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Sort</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Lysegrå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Hvid</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Andre...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>Nuværende lag-ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Tegningsenhed</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Linetype-skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Dimension Font</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+73"/>
        <location filename="../src/core/RLayer.cpp" line="+95"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="+81"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Skjult</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pixel Unit</source>
        <translation>Pixel-enhed</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Oprindelse</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+2"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Ejet af Reference</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Ekstern Reference</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Cirkulær (rekursiv) blokhenvisning opdaget:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Bloknavn:</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+95"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
        <source>Referenced Block</source>
        <translation>Blok, der er referencer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>Ekstern Reference</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+3"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Vinkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Kolonner</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Rækker</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Afstand mellem kolonnerne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Rækkeafstand</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attributter</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="-1"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layer</source>
        <translation>Lag</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+9"/>
        <source>Linetype</source>
        <translation>Linetype</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Linetype-skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Linjevægt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Farve</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Viste farve</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Trækningsrækkefølge</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Forældre Id</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Grænse</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Top</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Højde</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="-7"/>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Frossen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Sammenstyrtet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Plotbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Snappable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Off er Freeze</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="-23"/>
        <source>Tab Order</source>
        <translation>Fane rækkefølge</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min Grænser</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Grænseværdier</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Indsættelse Base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min. omfang</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Maksimale udstrækninger</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Tilpasset</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Håndtag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Beskyttet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Udvalgte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Objekt usynlig</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Arbejdssæt</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Tekst Position</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Almindelig tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Skrifttype navn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Teksthøjde</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Tekstbredde</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Tekst vinkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X Skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Linjeafstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Tilpasning</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Vandret</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Lodret</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>Bagudrettet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>Omvendt nedad</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Se center</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Se mål</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Samlet</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Frosne lag</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>Lag-ID</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linear measurement factor</source>
        <translation>Lineær målefaktor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Teksthøjde</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Dimension line gap</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>Pilens størrelse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Forøgelse af dimensionslinje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Udvidelse af linjeforlængelse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Forlængelseslinje offset</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Tekstposition vertikalt</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Overall scale</source>
        <translation>Samlet skala</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Text horizontal</source>
        <translation>Tekst horisontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>Krydsningsstørrelse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>Lineært format</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Decimaler</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Decimal separator</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Nul undertrykkelse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Angular-format</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Angulære decimaler</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Undertrykkelse af vinkelnulpunktet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Architectur tick</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Tekstfarve</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>Pileblok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Pileblok 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Pileblok 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Kræver udvælgelse</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Mønster</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>Af lag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Af blok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Kontinuerlig</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Grænse</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Center</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Stregpunkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Stiplet</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Opdele</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Skjult</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Phantom</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO-streg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO-streg mellemrum</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO lang streg-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO lang-streg dobbelt-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO lang-streg triple-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO lang-stregen kort-stregen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO lang-streg dobbelt-kort-streg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO stregpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO-dobbeltstreget punktum</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO bindestreg dobbelt-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO dobbelt-stregen dobbelt-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO bindestreg triple-punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO dobbelt-stregen tredobbelt-punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Forsyning af varmt vand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Varmt vand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gasledning</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Batting</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zig Zag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Spor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Fennelinie 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Fenceline 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Punkt 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Punkt 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Plante</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Vand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Afvanding</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Afvanding omvendt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Kommunikation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Elektrisk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Lav spænding</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Højspænding</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Overhead Power</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>Foul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>Foul Rising</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>Af lag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Af blok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
</TS>
